
====================================
`dscreate`
====================================

Flatiron Iron School Data Science Toolkit
=========================================

Installation
============
* run ``pip install dscreate``

Contents
--------

.. toctree::
   :maxdepth: 2
   :caption: USER DOCUMENTATION

   pages/cli_tools
   pages/solution_cells
   pages/inline_lessons
   pages/creating_tests

.. toctree::
   :maxdepth: 1
   :caption: DEVELOPER DOCUMENTATION

   pages/design_overview
   pages/code_documentation
   pages/config_options